# taitale

**taitale** a tool to utilize and craft pipelines with [ASKAPsoft](https://gitlab.com/ASKAPSDP) and other radio astronomy tools

taitale can work with either containers or native executables.

The goal is to provide an interface for radio astronomy tools in Python that would allow for easy interpolation with existing astronomy tools and packages like CASA and astropy.

## Installing

### Installing from PyPI

Available soon

### Building from source for development

```sh
# Install Poetry if you haven't already
curl -sSL https://install.python-poetry.org | python3 -

# Install dependencies and the package in development mode
poetry install --with test,dev

# Running tests
poetry run pytest

# Running style checks
poetry run ruff check .  # for linting
poetry run black .      # for formatting
```

### Building documentation

```sh
poetry install --with docs
poetry run sphinx-build -b html docs/source docs/build/html
```

## Documentation

The API documentation along with example workflows can be found [here](https://taitale.readthedocs.io/en/latest/cookbook.html)

## Why the name?

Taitale is the Etruscan name of Daedalus. This tools strives to excel in **crafting** pipelines
